package cn.com.qmth.examcloud.exchange.inner.api.provider;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.exchange.inner.api.SmsCloudService;
import cn.com.qmth.examcloud.exchange.inner.api.request.CaptureFailedAlarmReq;
import cn.com.qmth.examcloud.exchange.inner.api.request.CheckSmsCodeReq;
import cn.com.qmth.examcloud.exchange.inner.api.request.SendSmsCodeReq;
import cn.com.qmth.examcloud.exchange.inner.api.request.SendSmsReq;
import cn.com.qmth.examcloud.exchange.inner.api.response.CheckIdentifyingCodeResp;
import cn.com.qmth.examcloud.exchange.inner.api.response.SendSmsCodeResp;
import cn.com.qmth.examcloud.exchange.inner.api.response.SendSmsResp;
import cn.com.qmth.examcloud.exchange.inner.service.SmsService;
import cn.com.qmth.examcloud.support.cache.CacheHelper;
import cn.com.qmth.examcloud.support.cache.bean.SmsAssemblyCacheBean;
import cn.com.qmth.examcloud.web.bootstrap.PropertyHolder;
import cn.com.qmth.examcloud.web.support.ControllerSupport;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 短信发送
 */
@RestController
@RequestMapping("${$rmp.cloud.exchange.inner}" + "/sms")
public class SmsProvider extends ControllerSupport implements SmsCloudService {

    private static final long serialVersionUID = -1497756895732370672L;

    @Autowired
    private SmsService smsService;

    @Override
    @RequestMapping(method = RequestMethod.POST, value = "/sendSms")
    public SendSmsResp sendSms(@RequestBody @Valid @ApiParam(required = true) SendSmsReq req) {
        String smsAssemblyCode = req.getSmsAssemblyCode();
        List<String> phoneList = req.getPhoneList();
        Map<String, String> params = req.getParams();

        //获取短信配置信息
        SmsAssemblyCacheBean assemblyCacheBean = CacheHelper.getSmsAssembly(smsAssemblyCode);

        boolean virtualEnable = PropertyHolder.getBoolean("sms.virtual.enable",
                false);

        if (!virtualEnable) {
            try {
                smsService.sendSms(assemblyCacheBean, phoneList, params);
            } catch (Exception e) {
                // ignore
            }
        }

        SendSmsResp resp = new SendSmsResp();
        return resp;
    }

    @Override
    @RequestMapping(method = RequestMethod.POST, value = "/sendIdentifyingCode")
    public SendSmsCodeResp sendIdentifyingCode(@RequestBody @Valid @ApiParam(required = true) SendSmsCodeReq req) {

        SendSmsCodeResp sendSmsResp = new SendSmsCodeResp();
        try {
            smsService.sendSmsSecurityCode(req.getPhone(), req.getCode());
            sendSmsResp.setSuccess(true);
            sendSmsResp.setReturnMsg("发送成功");
        } catch (StatusException exception) {
            exception.printStackTrace();
            sendSmsResp.setSuccess(false);
            sendSmsResp.setReturnMsg(exception.getDesc());
        }
        return sendSmsResp;
    }

    @Override
    @RequestMapping(method = RequestMethod.POST, value = "/checkIdentifyingCode")
    public CheckIdentifyingCodeResp checkIdentifyingCode(@RequestBody @Valid @ApiParam(required = true) CheckSmsCodeReq req) {
        CheckIdentifyingCodeResp resp = new CheckIdentifyingCodeResp();
        try {
            smsService.validateSmsSecurityCode(req.getPhone(), req.getCode());
            resp.setSuccess(true);
            resp.setReturnMsg("校验成功");
        } catch (StatusException exception) {
            exception.printStackTrace();
            resp.setSuccess(false);
            resp.setReturnMsg(exception.getDesc());
        }
        return resp;
    }

}
